import { Channel } from './channel';
import { Message } from './message';
import { ChatKittyPaginator } from './pagination';
import { ChatKittyFailedResult, ChatKittySucceededResult } from './result';
export declare class Thread {
    id: string;
    type: string;
    name?: string;
    properties: unknown;
    createdTime: string;
    /** @internal */
    _relays: ThreadRelays;
    /** @internal */
    _topics: ThreadTopics;
    /** @internal */
    _actions: ThreadActions;
    /** @internal */
    _streams: ThreadStreams;
}
declare class ThreadRelays {
    channel: string;
    message: string;
}
declare class ThreadTopics {
    self: string;
    messages: string;
    keystrokes: string;
    typing: string;
}
declare class ThreadActions {
    message: string;
    keystrokes: string;
    read: string;
}
declare class ThreadStreams {
    messages: string;
}
export declare class CreateThreadRequest {
    channel: Channel;
    name: string;
    properties?: unknown;
}
export type CreateThreadResult = CreatedThreadResult | ChatKittyFailedResult;
export declare class CreatedThreadResult extends ChatKittySucceededResult {
    thread: Thread;
    constructor(thread: Thread);
}
export type ListThreadsRequest = ListChannelThreadsRequest;
export declare class ListChannelThreadsRequest {
    channel: Channel;
    filter?: ListChannelThreadsFilter;
}
export declare class ListChannelThreadsFilter {
    includeMainThread?: boolean;
    standalone?: boolean;
}
export type ListThreadsResult = ListThreadsSucceededResult | ChatKittyFailedResult;
export declare class ListThreadsSucceededResult extends ChatKittySucceededResult {
    paginator: ChatKittyPaginator<Thread>;
    constructor(paginator: ChatKittyPaginator<Thread>);
}
export declare class RetrieveThreadChannelRequest {
    thread: Thread;
}
export type RetrieveThreadChannelResult = RetrieveThreadChannelSucceededResult | ChatKittyFailedResult;
export declare class RetrieveThreadChannelSucceededResult extends ChatKittySucceededResult {
    channel: Channel;
    constructor(channel: Channel);
}
export declare class RetrieveThreadMessageRequest {
    thread: Thread;
}
export type RetrieveThreadMessageResult = RetrieveThreadMessageSucceededResult | ChatKittyFailedResult;
export declare class RetrieveThreadMessageSucceededResult extends ChatKittySucceededResult {
    message: Message;
    constructor(message: Message);
}
export declare class ReadThreadRequest {
    thread: Thread;
}
export type ReadThreadResult = ReadThreadSucceededResult | ChatKittyFailedResult;
export declare class ReadThreadSucceededResult extends ChatKittySucceededResult {
    thread: Thread;
    constructor(thread: Thread);
}
export {};
//# sourceMappingURL=thread.d.ts.map