import { Channel } from './channel';
import { ChatKittyModelReference } from './model';
import { ChatKittyPaginator } from './pagination';
import { ChatKittyFailedResult, ChatKittySucceededResult } from './result';
export interface BaseUser {
    id: number;
    name: string;
    displayName: string;
    displayPictureUrl: string;
    isGuest: boolean;
    presence: UserPresence;
    properties: unknown;
}
export declare class UserPresence {
    status: string;
    online: boolean;
}
export type User = BaseUser & {
    /** @internal */
    _relays: UserRelays;
};
declare class UserRelays {
    self: string;
    channelMember: string;
}
export type ChatKittyUserReference = ChatKittyModelReference | {
    username: string;
};
export declare class ListUsersRequest {
    filter?: ListUsersFilter;
}
export declare class ListUsersFilter {
    name?: string;
    displayName?: string;
    online?: boolean;
}
export type ListUsersResult = ListUsersSucceededResult | ChatKittyFailedResult;
export declare class ListUsersSucceededResult extends ChatKittySucceededResult {
    paginator: ChatKittyPaginator<User>;
    constructor(paginator: ChatKittyPaginator<User>);
}
export type RetrieveUserResult = ListUserSucceededResult | ChatKittyFailedResult;
export declare class ListUserSucceededResult extends ChatKittySucceededResult {
    user: User;
    constructor(user: User);
}
export declare class CheckUserIsChannelMemberRequest {
    user: User;
    channel: Channel;
}
export type CheckUserIsChannelMemberResult = CheckUserIsChannelMemberSucceededResult | ChatKittyFailedResult;
export declare class CheckUserIsChannelMemberSucceededResult extends ChatKittySucceededResult {
    isChannelMember: boolean;
    constructor(isChannelMember: boolean);
}
export declare class BlockUserRequest {
    user: User;
}
export type BlockUserResult = BlockUserSucceededResult | ChatKittyFailedResult;
export declare class BlockUserSucceededResult extends ChatKittySucceededResult {
    user: User;
    constructor(user: User);
}
export {};
//# sourceMappingURL=user.d.ts.map